function s=ilt(c,zc,sh,tau,h,us)

%General Information:
%The source/sink distribution is calculated with ilt.m, which uses two more
%functions Tl.m (Lagrangian timescale), sw.m (sigma(w) - standard deviation
%of vertical windspeed measured throughout the canopy, kn1.m and kn2.m (Kernel
%functions according to Raupach, FAM, 1989).
%For other real-world data sw.m needs to be changed according to the
%ecosystem. A generic shape has been proposed by Raupach, FAM, 1989. This
%example uses measured data from the AMAZON.
%Last updated: 07/2009

%Literature that should be cited when using this script:

%Karl, T.,Guenther, A., Turnipseed, A., Patton, E.G., and K. Jardine, 2008:
%Chemical sensing of plant stress at the ecosystem scale, Biogeosciences,
%5, 1287-1294.

%and

%Karl, T., Potosnak, M., Guenther, A., Clark, D., Walker, J., Herrick, J.D. and C. Geron, 2004:
%Exchange Processes of Volatile Organic Compounds above a Tropical Rainforest  Implications
%for Modeling Tropospheric Chemistry above Dense Vegetation, J. Geophys. Res., 109, D18306,
%10.1029/2004JD004738.

%INPUT
%c: concentration vector [g/m3]
%zc: height vector [m]
%sh: source layers [m]
%IMPORTANT when defining source vector - lower and upper limit of source layer sh MUST lie
%between lower and upper limit of concentration vector zc: e.g. sh(1)>zc(1) and sh(size(sh,2))<zc(size(zc,2)
%In addition it is important that none of the elements of the source vector (sh) overlap with none of the elements in the concentration vector. 
%tau: lifetime [s]
%h: height of canopy [m]
%us: friction velocity [m/s]

%OUTPUT
%s: source vector [g/m3/s]
ste=5;

zref=h;
dp=h*2/3; %displacment height 2/3 * hc
s0=0.5;
z0=1; 
n=size(zc,2);
m=size(sh,2);
r=7;

%Calculate dispersion Matrix

for i=1:n
      Lli=sw(zc(i),h,us)*Tl(zc(i),h,us,dp); %according to warland et al. (not used here)
      sigwi=sw(zc(i),h,us);
		for j=1:m
         Llj=sw(sh(j),h,us)*Tl(sh(j),h,us,dp); %according to warland et al. (not used here)
         
         %Raupach et al., Agr. For. Met., 1989
         if j>1
         	dzjs=sh(j)-sh(j-1);
      	else
         	dzjs=ste;
      	end
      	% alpha ij
      	hilf=0;
      	for l=1:r
         	if j>1
            	zjls=sh(j-1)+l*(sh(j)-sh(j-1))/r;
         	else
            	zjls=s0+l*(sh(j)-s0)/r;
            end
            %modify to include lifetime according to Patton et al., 2001.
         	hilf=hilf+(kn1(zc(i),zjls, sw(zjls,h,us), Tl(zjls,h,us,dp))+kn2(zc(i),zjls, sw(zjls,h,us), Tl(zjls,h,us,dp)))/(sw(zjls,h,us)/(1+Tl(zjls,h,us,dp)/tau));
      	end
      	alpha(i,j)=hilf*dzjs/r;  % alpha(n,j) corresponds to alpha(n+1,j) !
      
      	% beta ij
      
      	hilf2=0;
      	if i<n
         	for k=1:r*(n-i)
               zikc=zc(i)+k*(zc(n)-zc(i))/(r*(n-i));
         	   dzji=(zref-zc(i));
            	if j>1
               	if zikc <= sh(j-1)
               		hilf2=0+hilf2;
            		elseif sh(j-1)<zikc & zikc <= sh(j)
               		hilf2=(zikc-sh(j-1))/((sw(zikc,h,us)^2)*Tl(zikc,h,us,dp)/(1+Tl(zikc,h,us,dp)/tau))+hilf2;
            		elseif zikc > sh(j)
               		hilf2=dzjs/((sw(zikc,h,us)^2)*Tl(zikc,h,us,dp)/(1+Tl(zikc,h,us,dp)/tau))+hilf2;
               	end
            	else
               	if zikc <= s0
               		hilf2=0+hilf2;
            		elseif s0<zikc & zikc <= sh(j)
               		hilf2=(zikc-s0)/(sw(zikc,h,us)^2*Tl(zikc,h,us,dp)/(1+Tl(zikc,h,us,dp)/tau))+hilf2;
            		elseif zikc > sh(j)
               		hilf2=dzjs/(sw(zikc,h,us)^2*Tl(zikc,h,us,dp)/(1+Tl(zikc,h,us,dp)/tau))+hilf2;
               	end
            	end
      		end
         	beta(i,j)=dzji*hilf2/(r*(n+1-i));
            %calculate D according to Warland et al. (not used here)
         	if zc(i)>sh(j)
            	dmw(i,j)=-(1-exp(-(zc(i)-sh(j))^2/(2*ste^2)))/(2*sigwi*Lli*(1-exp(-sqrt(pi/2)*(zc(i)-sh(j))*2/(Lli+Llj))))-(1-exp(-(zc(i)+sh(j))^2/(2*ste^2)))/(2*sigwi*Lli*(1-exp(-sqrt(pi/2)*(zc(i)+sh(j))*2/(Lli+Llj))));
         	elseif zc(i)==sh(j)
            	dmw(i,j)=-(1-exp(-(zc(i)+sh(j))^2/(2*ste^2)))/(2*sigwi*Lli*(1-exp(-sqrt(pi/2)*(zc(i)+sh(j))*2/(Lli+Llj))));
         	elseif zc(i)<sh(j)
            	dmw(i,j)=(1-exp(-(zc(i)-sh(j))^2/(2*ste^2)))/(2*sigwi*Lli*(1-exp(-sqrt(pi/2)*(sh(j)-zc(i))*2/(Lli+Llj))))-(1-exp(-(zc(i)+sh(j))^2/(2*ste^2)))/(2*sigwi*Lli*(1-exp(-sqrt(pi/2)*(zc(i)+sh(j))*2/(Lli+Llj))));
				end
         end
   	end
	end
	for i=1:n-1
   	d(i,1:m)=(alpha(i,1:m)-alpha(n,1:m)+beta(i,1:m));
    end

%calculate source/sink distribution
s=d\(c(1:(size(c,2)-1))-c(size(c,2)))';

